Bloom post-process object holding internal states and resources.

Create with [CreateBloomFromAssets] or [CreateBloomFromFile], use with [ApplyBloom], finally call [DestroyBloom] to dispose of resources when done.